.. blastpipe documentation master file, created by
   sphinx-quickstart on Wed May 10 21:03:02 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. Copyright 2023 Ross J. Duff MSc 
   The copyright holder licenses this file
   to you under the Apache License, Version 2.0 (the
   "License"); you may not use this file except in compliance
   with the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing,
   software distributed under the License is distributed on an
   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
   KIND, either express or implied.  See the License for the
   specific language governing permissions and limitations
   under the License.

Welcome to blastpipe's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

License
=======
.. image:: https://i.creativecommons.org/l/by/4.0/88x31.png
   :alt: Creative Commons License
   :target: http://creativecommons.org/licenses/by/4.0/

The content of this project itself is licensed under a
`Creative Commons Attribution 4.0 International License
<https://creativecommons.org/licenses/by/4.0/>`_, 
and the underlying source code used to build, format, and display that 
content is licensed under version 2.0 of the Apache License.

Modules
=======

.. autosummary::
   :toctree: modules

   blastpipe
   blastpipe.backports
   blastpipe.buffer
   blastpipe.loop
   blastpipe.malloc
   blastpipe.mixin
   blastpipe.sequence
   blastpipe.tailcall

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
